========================================
``psyclone.psyir.nodes.array_reference``
========================================

.. automodule:: psyclone.psyir.nodes.array_reference

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.array_reference


Classes
=======

- :py:class:`ArrayReference`:
  Node representing a reference to an element or elements of an Array.


.. autoclass:: ArrayReference
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArrayReference
      :parts: 1
